NullTerminatedBuf

Struct NullTerminatedBuf 

pub struct NullTerminatedBuf(/* private fields */);
A null terminated memory buffer.

Implementations

Source

impl NullTerminatedBuf

pub fn from_reader(reader: &mut dyn Read) -> Result<NullTerminatedBuf, Error>

Create from a reader and null terminate.

pub fn from_file(f: &mut File) -> Result<NullTerminatedBuf, Error>

Create from a file and null terminate it.

pub fn from_slice_copy(s: &[u8]) -> NullTerminatedBuf

Create by copying a slice and appending null-termination.

pub fn from_slice_check(s: &[u8]) -> NullTerminatedBuf

Create from a slice that may already be null-terminated.

pub fn from_str_copy(s: &str) -> NullTerminatedBuf

Create by copying a string and appending null-termination.

pub fn from_str_check(s: &str) -> NullTerminatedBuf

Create from a string that may already be null-terminated.

pub fn len(&self) -> usize

Return the length of the data including the null terminator.

pub fn is_empty(&self) -> bool

Just a placeholder always returning true, since the there is always at least a null terminator.

pub fn as_bytes(&self) -> &[u8]