Warning

Enum Warning 

pub enum Warning {
    NoWarning,
    UndefinedVariable,
    DirectEval,
    EvalDisabled,
    UnresolvedStaticRequire,
    Misc,
}
A warning category. Ported verbatim from hermes/Support/Warnings.def. NoWarning is special and must remain the first variant.

Variants



NoWarning

All warnings. Special; its description is only used in the context of -Werror and -Wno-error.



UndefinedVariable

Warning when an undefined variable is referenced. (-Wundefined-variable)



DirectEval

Warning when attempting a direct (local) eval. (-Wdirect-eval)



EvalDisabled

Warning if invoking eval() when it is disabled. (-Weval-disabled)



UnresolvedStaticRequire

Warning when require calls cannot be resolved statically. (-Wunresolved-static-require)



Misc

Miscellaneous warnings. (hidden: -Wmisc)

Implementations

Source

impl Warning

pub const COUNT: usize = 6

Number of warning categories (the C++ _NumWarnings sentinel).

pub fn index(self) -> usize

The dense 0-based index of this category, for indexing status bitsets.